<?php

namespace Drupal\uw_cfg_common\Plugin\views\field;

use Drupal\views\Plugin\views\field\Dropbutton;
use Drupal\views\ResultRow;

/**
 * Provides a handler that renders links as dropbutton with access check.
 *
 * Identical to parent class except that render() removes links for which the
 * user has no access.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("uwdropbutton")
 */
class UWDropbutton extends Dropbutton {

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    $links = [];
    foreach ($this->getLinks() as $link) {
      if ($link['url']->access()) {
        $links[] = $link;
      }
    }

    if (!empty($links)) {
      return [
        '#type' => 'dropbutton',
        '#links' => $links,
      ];
    }
    else {
      return '';
    }
  }

}
